==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2107_155.zip: ronportal/ronportal/skoleni/absolvovaniskoleniform.php <==
<?php
/**
 * User: pavel.rudol
 * Date: 14.6.2016
 * Time: 14:28
 */

namespace RonPortal\Skoleni;

use Exception;
use Ron\Controls\FormField;
use Ron\DateUtils;
use Ron\DB\Database;
use Ron\DB\SqlStatement;
use Ron\MessageManager;
use Ron\StringUtils;
use Ron\TextManager;
use RonPortal\Controls\OsobaFormField;
use RonPortal\Controls\RonPortalForm;
use RonPortal\Controls\UserLoginFormField;
use RonPortal\Dokumenty\DokumentyUtils;
use RonPortal\PracovniPomer;
use RonPortal\RonPortalDBRecord;
use RonPortal\RonPortalSettings;
use RonPortal\RonPortalXMLEvents;


class OsobaSkoleniField extends OsobaFormField
{
    public function __construct($prava, $datumPlatnostiPP, $pp)
    {
        //$this->pracovniPomer = $pp;
        parent::__construct($prava, $datumPlatnostiPP, $pp);
    }

    function showFieldContent($database, $value, $canEdit, $insert, $rowData)
    {
        if ($insert) {
            parent::showFieldContent($database, $value, $canEdit, $insert, $rowData);
        }
        elseif ($this->pracovniPomer) {
            echo
                '<input type="hidden" name="' . $this->fieldName . '" value="' . $this->pracovniPomer->idPP . '" />' .
                $this->pracovniPomer->jmenoPrijmeniKratke .
                "\n";
        }
    }
}

///**
// * Class KurzField
// * @package Ron\RonPortal
// */
//class KurzField extends FormField
//{
//
//    /** @var Database $database */
//    public $database;
//
//    /**
//     * KurzField constructor.
//     * @param Database $database
//     */
//    public function __construct($database)
//    {
//        parent::__construct(FormField::FIELD_TYPE_SELECT);
//
//        $this->database = $database;
//        $this->maxLength = 10;
//    }
//
//
//
//    /**
//     * @param Database $database
//     * @param mixed $value
//     * @param bool $canEdit
//     * @param bool $insert
//     * @param array $rowData
//     * @throws DBException
//     */
//    public function showFieldContent($database, $value, $canEdit, $insert, $rowData)
//    {
//        //parent::showFieldContent($database, $value, $canEdit, $insert, $rowData);
//
//        $params = $database->createParameters();
//
//        $sql =
//            'SELECT CisloSkoleni, Popis FROM Skoleni' .
//            ' WHERE DruhSkoleni = ' . $params->addParameter($rowData ? $rowData[1] : '') .
//            ' AND Skoleni.StavSkoleni IN (0,1)';
////        $sql .= " AND Skoleni.DatumPocatkuSkoleni <= " . $params->addParameter($this->database->timestampToParam($rowData[9]));
////        $sql .= " AND (Skoleni.DatumUkonceniSkoleni  >= " . $params->addParameter($this->database->timestampToParam($rowData[9]));
////        $sql .= " OR Skoleni.DatumUkonceniSkoleni IS NULL )";
//
//        if (true) {
//            $combo = new ComboBox('Kurz');
//            $combo->emptyRow = '';
//            $combo->loadData($database, $sql, '', $params);
//            $combo->render();
//        } else {
//            echo '<input class="app_input" type="text" disabled="disabled" name="Kurz" value="' . $rowData[2] .  '">';
//            echo '<input class="app_input" type="hidden" name="Kurz" value="' . $rowData[2] . '">';
//        }
//    }
//
//
//    function createDBRecordField($database, $tableName, $insert, $utf8 = false)
//    {
//        $field = new DBRecordField($this->sqlFieldName, '', $this->readOnly, $this->maxLength);
//        if (!$this->readOnly) {
//            if (isset($_POST['Kurz']) && $_POST['Kurz'] != '') {
//                $field->setValue($_POST['Kurz']);
//            }
//        } else {
//            $field->setValue("");
//        }
//        return $field;
//    }
//}



class AbsolvovaniSkoleniForm extends RonPortalForm
{
    private $osobaRC;
    private $druhSkoleni;
    private $datumPovinnosti;

    /**
     * SkoleniForm constructor.
     * @param Database $database
     * @param PracovniPomer $pp
     * @param string $druhSkoleni
     * @param int $datumPovinnosti
     */
    public function __construct($database, $pp, $druhSkoleni, $datumPovinnosti)
    {
        parent::__construct($database);

        $this->osobaRC = $pp ? $pp->rc : null;
        $this->druhSkoleni = $druhSkoleni;
        $this->datumPovinnosti = $datumPovinnosti;

        $this->code = 'formskoleni';

        $this->htmlAction = '?menuid=skoleni&action=zapisabsolvovani';
        $this->stornoAction = '?menuid=skoleni';

        $this->sqlTableName = 'GenerovaneSkoleni';

        $this->xmlEventBeforePost = RonPortalXMLEvents::SKOLENI_ABSOLVOVANI_BEFORE;
        $this->xmlEventAfterPost = RonPortalXMLEvents::SKOLENI_ABSOLVOVANI_AFTER;

        $this->sqlSelectPart =
            'RC, DruhSkoleni, DatumVznikuPovinnosti, DuvodSkoleni, DatumZapisu, DatumSkoleni, PozadovaneDatumSkoleni, ' . // 0 - 6
            'PozadovanaPlatnostDo, Vlozil, CisloSkoleni, DatumPrihlasky, DatumPoslednihoSkoleni, Prihlasil, Potvrzeni, ' . // 7 - 13
            'Povinne, {fn_CASTWIDEMEMO(Poznamka)}, Kredity, Generovane, PopisSkoleni, CenaZKurzu, CenaIndividualni, CenaCelkova, HodinyIndividualni, PrihlasenoZAplikace'; // 14 - 23

        $this->addField(new OsobaSkoleniField('skoleni_absolvovani', DateUtils::now(), $pp))
            ->setCode('field-osoba')
            ->setCaption('Osoba');

        $this->addField(FormField::FIELD_TYPE_SELECT)
            ->setFieldName('DruhSkoleni') ->setSqlFieldIndex(1) ->setPrimary(true) ->setReadOnly(true) ->setRequired(true)
            ->setCode('field-druhskoleni')
            ->setCaption('Druh_skoleni')
            ->setSelectSql('SELECT Kod, Popis FROM DruhSkoleni WHERE Aktivni = 1 AND Elearning = 0 ORDER BY Popis');

        $this->addField(FormField::FIELD_TYPE_DATE)
            ->setFieldName('DatumSkoleni') ->setSqlFieldIndex(5) ->setRequired(true)
            ->setCode('field-datumskoleni')
            ->setCaption('Skoleni_datum') ->setDefaultValue(StringUtils::format('date',DateUtils::today()))
            ->setUseDefaultValueToEditNull(true);

        $this->addField(FormField::FIELD_TYPE_SELECT)
            ->setFieldName('DuvodSkoleni') ->setSqlFieldIndex(3) ->setRequired(true) ->setReadOnly(true)
            ->setCode('field-duvodskoleni')
            ->setCaption('Skoleni_duvod') ->setDefaultValue(1) ->setDataType('int')
            ->setSelectSql('SELECT Kod, Popis FROM S_DuvodSkoleni WHERE (%FILTER%) ORDER BY %ORDER%', '1 = 1', 'Popis');

        $this->addField(FormField::FIELD_TYPE_SELECT)
            ->setFieldName('Potvrzeni') ->setRequired(true) ->setDefaultValue(3) ->setDataType('int')   //FORM_FIELD_SQL_INDEX => 13, - u vygenerovanych naroku je jine potvrzeni
            ->setCode('field-potvrzeni')
            ->setCaption('Skoleni_potvrzeni')
            ->setSelectSql('SELECT Kod, Popis FROM S_StavPotvrzeni WHERE (%FILTER%) ORDER BY %ORDER%', 'KOD IN (3,4,7,8)', 'Popis'); //Pro JiSz pridano 7,8

//        $this->addField(new KurzField($database))
//            ->setFieldName('CisloSkoleni')
//            ->setCode('field-cisloskoleni')
//            ->setCaption('Skoleni_druh_kurzu');
        if ($druhSkoleni) {
            $params = $database->createParameters();

            $this->addField(FormField::FIELD_TYPE_SELECT)
                ->setFieldName('CisloSkoleni')->setSqlFieldIndex(9)
                ->setCode('field-cisloskoleni')
                ->setCaption('Skoleni_druh_kurzu')
                ->setSelectSql( new SqlStatement(
                    'SELECT CisloSkoleni, Popis FROM Skoleni' .
                    ' WHERE DruhSkoleni = ' . $params->addParameter($druhSkoleni) .
                    ' AND (%FILTER%)' .
                    ' ORDER BY %ORDER%',
                    $params), 'Skoleni.StavSkoleni IN (0,1)', 'Popis'
                    );
        }

        $this->addField(new UserLoginFormField(true, 'Vlozil'))
            ->setCode('field-vlozil');

        $this->addField()
            ->setFieldName('PopisSkoleni') ->setSqlFieldIndex(18)
            ->setCode('field-popisskoleni')
            ->setCaption('Popis_skoleni');

        $this->addField(FormField::FIELD_TYPE_FILE)
            ->setFieldName('dokument') ->setCaption('Skoleni_dokument')
            ->setCode('field-dokument');

        $this->addField()
            ->setFieldName('*dokument_popis')
            ->setCode('field-popisdokumentu')
            ->setCaption('Skoleni_dokument_popis');

        $this->addField(FormField::FIELD_TYPE_MEMO)
            ->setFieldName('Poznamka') ->setSqlFieldIndex(15) ->setCaption('Poznamka')
            ->setCode('field-poznamka');
    }

    function renderCommonFields()
    {
        parent::renderCommonFields();
        echo '<input type="hidden" name="DatumPovinnosti" value="' . ($this->datumPovinnosti ?: DateUtils::now()) . '"/>';
    }


    function checkRequiredFields($edit)
    {
        if ((is_uploaded_file($_FILES['dokument']['tmp_name'])) && ($_POST['dokument_popis'] == '')) {
            MessageManager::addErrorMessage(TextManager::_('Skoleni_dokument_chybi_popis'), 'dokument_popis');
            return false;
        }
        return parent::checkRequiredFields($edit);
    }


//    function createDBRecord()
//    {
//        $rec = parent::createDBRecord();
//
//        $rec->addField('RC', '', true, 15, $this->osobaRC);
//        $rec->addField('DatumVznikuPovinnosti', 'timestamp', true, 0, $this->datumPovinnosti);
//        $rec->addField('DatumZapisu', 'timestamp', true, 0, DateUtils::today());
//        $rec->addField('Generovane', 'int', true, 0, 0); //vlozeno rucne
//        $rec->addField('PrihlasenoZAplikace', 'int', true, 0, 1); // 1 = portal
//
//        return $rec;
//    }

    function createDBRecordFields($rec, $insert)
    {
        $rec->addField('RC', '', true, 15, $this->osobaRC);
        $rec->addField('DatumVznikuPovinnosti', 'timestamp', true, 0, $this->datumPovinnosti);
        $rec->addField('DatumZapisu', 'timestamp', true, 0, DateUtils::today());
        $rec->addField('Generovane', 'int', true, 0, 0); //vlozeno rucne
        $rec->addField('PrihlasenoZAplikace', 'int', true, 0, 1); // 1 = portal

        parent::createDBRecordFields($rec, $insert);
    }


    /**
     * @return SqlStatement
     */
    function getWhereCondition()
    {
        $params = $this->database->createParameters();

        return new SqlStatement(
            'RC = ' . $params->addParameter($this->osobaRC) .
            ' AND DruhSkoleni = ' . $params->addParameter($this->druhSkoleni) .
            ' AND DatumVznikuPovinnosti = ' . $params->addParameter($this->database->timestampToParam($this->datumPovinnosti)),
            $params);
    }

    function setDBRecord($rec)
    {
        parent::setDBRecord($rec);

        $where = $this->getWhereCondition();
        $rec->setWhere($where->sqlText, $where->parameters);
    }

    /**
     * @param RonPortalDBRecord $rec
     * @return mixed
     * @throws Exception
     */
    function beforeInsertRecord($rec)
    {
        //vkladat jen pro nevygenerovane naroky pro druh skoleni
        if (SkoleniUtils::existujeNavrhTypuSkoleni($this->database,
            $rec['RC'], $rec['DruhSkoleni']))
        {
            throw new Exception(TextManager::_('Skoleni_existuje_navrh'));
        }        

        return $rec->executeXmlEvents(RonPortalXMLEvents::SKOLENI_ABSOLVOVANI_BEFORE, 'insert');
    }

    /**
     * @param RonPortalDBRecord $rec
     * @return mixed
     */
    function beforeUpdateRecord($rec)
    {
        return $rec->executeXmlEvents(RonPortalXMLEvents::SKOLENI_ABSOLVOVANI_BEFORE, 'update');
    }

    /**
     * @param RonPortalDBRecord $rec
     * @return mixed
     */
    function afterInsertRecord($rec)
    {
        $this->uploadDokument($rec);

        return $rec->executeXmlEvents(RonPortalXMLEvents::SKOLENI_ABSOLVOVANI_AFTER, 'insert');
    }

    /**
     * @param RonPortalDBRecord $rec
     * @return mixed
     */
    function afterUpdateRecord($rec)
    {
        $this->uploadDokument($rec);

        return $rec->executeXmlEvents(RonPortalXMLEvents::SKOLENI_ABSOLVOVANI_AFTER, 'update');
    }

    private function uploadDokument($rec)
    {
        if (is_uploaded_file($_FILES['dokument']['tmp_name'])) {
            try {
                $idDokumentu = DokumentyUtils::vlozDokument($this->database,
                    'dokument', RonPortalSettings::getIntValue('skoleni_typ_dokumentu'),
                    $_POST['dokument_popis'], $this->dbLogSrcDescription);

                $recDokumentOsoby = new RonPortalDBRecord($this->database, 'DokumentyOsoby', $this);
                $recDokumentOsoby->addStringField('RC', true, 15, $rec['RC']);
                $recDokumentOsoby->addIntField('id', true, $idDokumentu);
                $recDokumentOsoby->addStringField('GSk_RC', false, 15, $rec['RC']);
                $recDokumentOsoby->addStringField('GSk_DruhSkoleni', false, 10, $rec['DruhSkoleni']);
                $recDokumentOsoby->addTimestampField('GSk_Datum', true, $rec['DatumVznikuPovinnosti']);

                $recDokumentOsoby->insertRecord();
            } catch (Exception $e) {
                MessageManager::addErrorMessage($e);
            }
        }
    }
}

==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2206_162.zip: ronportal/ronportal/skoleni/absolvovaniskoleniform.php <==
<?php
/**
 * User: pavel.rudol
 * Date: 14.6.2016
 * Time: 14:28
 */

namespace RonPortal\Skoleni;

use Exception;
use Ron\Controls\FormField;
use Ron\DateUtils;
use Ron\DB\Database;
use Ron\DB\SqlStatement;
use Ron\MessageManager;
use Ron\StringUtils;
use Ron\TextManager;
use RonPortal\Controls\OsobaFormField;
use RonPortal\Controls\RonPortalForm;
use RonPortal\Controls\UserLoginFormField;
use RonPortal\Dokumenty\DokumentyUtils;
use RonPortal\PracovniPomer;
use RonPortal\RonPortalDBRecord;
use RonPortal\RonPortalSettings;
use RonPortal\RonPortalXMLEvents;


class OsobaSkoleniField extends OsobaFormField
{
    public function __construct($prava, $datumPlatnostiPP, $pp)
    {
        //$this->pracovniPomer = $pp;
        parent::__construct($prava, $datumPlatnostiPP, $pp);
    }

    function showFieldContent($database, $value, $canEdit, $insert, $rowData)
    {
        if ($insert) {
            parent::showFieldContent($database, $value, $canEdit, $insert, $rowData);
        }
        elseif ($this->pracovniPomer) {
            echo
                '<input type="hidden" name="' . $this->fieldName . '" value="' . $this->pracovniPomer->idPP . '" />' .
                $this->pracovniPomer->jmenoPrijmeniKratke .
                "\n";
        }
    }
}

///**
// * Class KurzField
// * @package Ron\RonPortal
// */
//class KurzField extends FormField
//{
//
//    /** @var Database $database */
//    public $database;
//
//    /**
//     * KurzField constructor.
//     * @param Database $database
//     */
//    public function __construct($database)
//    {
//        parent::__construct(FormField::FIELD_TYPE_SELECT);
//
//        $this->database = $database;
//        $this->maxLength = 10;
//    }
//
//
//
//    /**
//     * @param Database $database
//     * @param mixed $value
//     * @param bool $canEdit
//     * @param bool $insert
//     * @param array $rowData
//     * @throws DBException
//     */
//    public function showFieldContent($database, $value, $canEdit, $insert, $rowData)
//    {
//        //parent::showFieldContent($database, $value, $canEdit, $insert, $rowData);
//
//        $params = $database->createParameters();
//
//        $sql =
//            'SELECT CisloSkoleni, Popis FROM Skoleni' .
//            ' WHERE DruhSkoleni = ' . $params->addParameter($rowData ? $rowData[1] : '') .
//            ' AND Skoleni.StavSkoleni IN (0,1)';
////        $sql .= " AND Skoleni.DatumPocatkuSkoleni <= " . $params->addParameter($this->database->timestampToParam($rowData[9]));
////        $sql .= " AND (Skoleni.DatumUkonceniSkoleni  >= " . $params->addParameter($this->database->timestampToParam($rowData[9]));
////        $sql .= " OR Skoleni.DatumUkonceniSkoleni IS NULL )";
//
//        if (true) {
//            $combo = new ComboBox('Kurz');
//            $combo->emptyRow = '';
//            $combo->loadData($database, $sql, '', $params);
//            $combo->render();
//        } else {
//            echo '<input class="app_input" type="text" disabled="disabled" name="Kurz" value="' . $rowData[2] .  '">';
//            echo '<input class="app_input" type="hidden" name="Kurz" value="' . $rowData[2] . '">';
//        }
//    }
//
//
//    function createDBRecordField($database, $tableName, $insert, $utf8 = false)
//    {
//        $field = new DBRecordField($this->sqlFieldName, '', $this->readOnly, $this->maxLength);
//        if (!$this->readOnly) {
//            if (isset($_POST['Kurz']) && $_POST['Kurz'] != '') {
//                $field->setValue($_POST['Kurz']);
//            }
//        } else {
//            $field->setValue("");
//        }
//        return $field;
//    }
//}



class AbsolvovaniSkoleniForm extends RonPortalForm
{
    private $osobaRC;
    private $druhSkoleni;
    private $datumPovinnosti;

    /**
     * SkoleniForm constructor.
     * @param Database $database
     * @param PracovniPomer $pp
     * @param string $druhSkoleni
     * @param int $datumPovinnosti
     */
    public function __construct($database, $pp, $druhSkoleni, $datumPovinnosti)
    {
        parent::__construct($database);

        $this->osobaRC = $pp ? $pp->rc : null;
        $this->druhSkoleni = $druhSkoleni;
        $this->datumPovinnosti = $datumPovinnosti;

        $this->code = 'formskoleni';

        $this->htmlAction = '?menuid=skoleni&action=zapisabsolvovani';
        $this->stornoAction = '?menuid=skoleni';

        $this->sqlTableName = 'GenerovaneSkoleni';

        $this->xmlEventBeforePost = RonPortalXMLEvents::SKOLENI_ABSOLVOVANI_BEFORE;
        $this->xmlEventAfterPost = RonPortalXMLEvents::SKOLENI_ABSOLVOVANI_AFTER;

        $this->sqlSelectPart =
            'RC, DruhSkoleni, DatumVznikuPovinnosti, DuvodSkoleni, DatumZapisu, DatumSkoleni, PozadovaneDatumSkoleni, ' . // 0 - 6
            'PozadovanaPlatnostDo, Vlozil, CisloSkoleni, DatumPrihlasky, DatumPoslednihoSkoleni, Prihlasil, Potvrzeni, ' . // 7 - 13
            'Povinne, {fn_CASTWIDEMEMO(Poznamka)}, Kredity, Generovane, PopisSkoleni, CenaZKurzu, CenaIndividualni, CenaCelkova, HodinyIndividualni, PrihlasenoZAplikace'; // 14 - 23

        $this->addField(new OsobaSkoleniField('skoleni_absolvovani', DateUtils::now(), $pp))
            ->setCode('field-osoba')
            ->setCaption('Osoba');

        $this->addField(FormField::FIELD_TYPE_SELECT)
            ->setFieldName('DruhSkoleni') ->setSqlFieldIndex(1) ->setPrimary(true) ->setReadOnly(true) ->setRequired(true)
            ->setCode('field-druhskoleni')
            ->setCaption('Druh_skoleni')
            ->setSelectSql('SELECT Kod, Popis FROM DruhSkoleni WHERE Aktivni = 1 AND Elearning = 0 ORDER BY Popis');

        $this->addField(FormField::FIELD_TYPE_DATE)
            ->setFieldName('DatumSkoleni') ->setSqlFieldIndex(5) ->setRequired(true)
            ->setCode('field-datumskoleni')
            ->setCaption('Skoleni_datum') ->setDefaultValue(StringUtils::format('date',DateUtils::today()))
            ->setUseDefaultValueToEditNull(true);

        $this->addField(FormField::FIELD_TYPE_SELECT)
            ->setFieldName('DuvodSkoleni') ->setSqlFieldIndex(3) ->setRequired(true) ->setReadOnly(true)
            ->setCode('field-duvodskoleni')
            ->setCaption('Skoleni_duvod') ->setDefaultValue(1) ->setDataType('int')
            ->setSelectSql('SELECT Kod, Popis FROM S_DuvodSkoleni WHERE (%FILTER%) ORDER BY %ORDER%', '1 = 1', 'Popis');

        $this->addField(FormField::FIELD_TYPE_SELECT)
            ->setFieldName('Potvrzeni') ->setRequired(true) ->setDefaultValue(3) ->setDataType('int')   //FORM_FIELD_SQL_INDEX => 13, - u vygenerovanych naroku je jine potvrzeni
            ->setCode('field-potvrzeni')
            ->setCaption('Skoleni_potvrzeni')
            ->setSelectSql('SELECT Kod, Popis FROM S_StavPotvrzeni WHERE (%FILTER%) ORDER BY %ORDER%', 'KOD IN (3,4,7,8)', 'Popis'); //Pro JiSz pridano 7,8

//        $this->addField(new KurzField($database))
//            ->setFieldName('CisloSkoleni')
//            ->setCode('field-cisloskoleni')
//            ->setCaption('Skoleni_druh_kurzu');
        if ($druhSkoleni) {
            $params = $database->createParameters();

            $this->addField(FormField::FIELD_TYPE_SELECT)
                ->setFieldName('CisloSkoleni')->setSqlFieldIndex(9)
                ->setCode('field-cisloskoleni')
                ->setCaption('Skoleni_druh_kurzu')
                ->setSelectSql( new SqlStatement(
                    'SELECT CisloSkoleni, Popis FROM Skoleni' .
                    ' WHERE DruhSkoleni = ' . $params->addParameter($druhSkoleni) .
                    ' AND (%FILTER%)' .
                    ' ORDER BY %ORDER%',
                    $params), 'Skoleni.StavSkoleni IN (0,1)', 'Popis'
                    );
        }

        $this->addField(new UserLoginFormField(true, 'Vlozil'))
            ->setCode('field-vlozil');

        $this->addField()
            ->setFieldName('PopisSkoleni') ->setSqlFieldIndex(18)
            ->setCode('field-popisskoleni')
            ->setCaption('Popis_skoleni');

        $this->addField(FormField::FIELD_TYPE_FILE)
            ->setFieldName('*dokument') ->setCaption('Skoleni_dokument')
            ->setCode('field-dokument');

        $this->addField()
            ->setFieldName('*dokument_popis')
            ->setCode('field-popisdokumentu')
            ->setCaption('Skoleni_dokument_popis');

        $this->addField(FormField::FIELD_TYPE_MEMO)
            ->setFieldName('Poznamka') ->setSqlFieldIndex(15) ->setCaption('Poznamka')
            ->setCode('field-poznamka');
    }

    function renderCommonFields()
    {
        parent::renderCommonFields();
        echo '<input type="hidden" name="DatumPovinnosti" value="' . ($this->datumPovinnosti ?: DateUtils::now()) . '"/>';
    }


    function checkRequiredFields($edit)
    {
        if ((is_uploaded_file($_FILES['dokument']['tmp_name'])) && ($_POST['dokument_popis'] == '')) {
            MessageManager::addErrorMessage(TextManager::_('Skoleni_dokument_chybi_popis'), 'dokument_popis');
            return false;
        }
        return parent::checkRequiredFields($edit);
    }


//    function createDBRecord()
//    {
//        $rec = parent::createDBRecord();
//
//        $rec->addField('RC', '', true, 15, $this->osobaRC);
//        $rec->addField('DatumVznikuPovinnosti', 'timestamp', true, 0, $this->datumPovinnosti);
//        $rec->addField('DatumZapisu', 'timestamp', true, 0, DateUtils::today());
//        $rec->addField('Generovane', 'int', true, 0, 0); //vlozeno rucne
//        $rec->addField('PrihlasenoZAplikace', 'int', true, 0, 1); // 1 = portal
//
//        return $rec;
//    }

    function createDBRecordFields($rec, $insert)
    {
        $rec->addField('RC', '', true, 15, $this->osobaRC);
        $rec->addField('DatumVznikuPovinnosti', 'timestamp', true, 0, $this->datumPovinnosti);
        $rec->addField('DatumZapisu', 'timestamp', true, 0, DateUtils::today());
        $rec->addField('Generovane', 'int', true, 0, 0); //vlozeno rucne
        $rec->addField('PrihlasenoZAplikace', 'int', true, 0, 1); // 1 = portal

        parent::createDBRecordFields($rec, $insert);
    }


    /**
     * @return SqlStatement
     */
    function getWhereCondition()
    {
        $params = $this->database->createParameters();

        return new SqlStatement(
            'RC = ' . $params->addParameter($this->osobaRC) .
            ' AND DruhSkoleni = ' . $params->addParameter($this->druhSkoleni) .
            ' AND DatumVznikuPovinnosti = ' . $params->addParameter($this->database->timestampToParam($this->datumPovinnosti)),
            $params);
    }

    function setDBRecord($rec)
    {
        parent::setDBRecord($rec);

        $where = $this->getWhereCondition();
        $rec->setWhere($where->sqlText, $where->parameters);
    }

    /**
     * @param RonPortalDBRecord $rec
     * @return mixed
     * @throws Exception
     */
    function beforeInsertRecord($rec)
    {
        //vkladat jen pro nevygenerovane naroky pro druh skoleni
        if (SkoleniUtils::existujeNavrhTypuSkoleni($this->database,
            $rec['RC'], $rec['DruhSkoleni']))
        {
            throw new Exception(TextManager::_('Skoleni_existuje_navrh'));
        }        

        return $rec->executeXmlEvents(RonPortalXMLEvents::SKOLENI_ABSOLVOVANI_BEFORE, 'insert');
    }

    /**
     * @param RonPortalDBRecord $rec
     * @return mixed
     */
    function beforeUpdateRecord($rec)
    {
        return $rec->executeXmlEvents(RonPortalXMLEvents::SKOLENI_ABSOLVOVANI_BEFORE, 'update');
    }

    /**
     * @param RonPortalDBRecord $rec
     * @return mixed
     */
    function afterInsertRecord($rec)
    {
        $this->uploadDokument($rec);

        return $rec->executeXmlEvents(RonPortalXMLEvents::SKOLENI_ABSOLVOVANI_AFTER, 'insert');
    }

    /**
     * @param RonPortalDBRecord $rec
     * @return mixed
     */
    function afterUpdateRecord($rec)
    {
        $this->uploadDokument($rec);

        return $rec->executeXmlEvents(RonPortalXMLEvents::SKOLENI_ABSOLVOVANI_AFTER, 'update');
    }

    private function uploadDokument($rec)
    {
        if (is_uploaded_file($_FILES['dokument']['tmp_name'])) {
            try {
                $idDokumentu = DokumentyUtils::vlozDokument($this->database,
                    'dokument', RonPortalSettings::getIntValue('skoleni_typ_dokumentu'),
                    $_POST['dokument_popis'], $this->dbLogSrcDescription);

                $recDokumentOsoby = new RonPortalDBRecord($this->database, 'DokumentyOsoby', $this);
                $recDokumentOsoby->addStringField('RC', true, 15, $rec['RC']);
                $recDokumentOsoby->addIntField('id', true, $idDokumentu);
                $recDokumentOsoby->addStringField('GSk_RC', false, 15, $rec['RC']);
                $recDokumentOsoby->addStringField('GSk_DruhSkoleni', false, 10, $rec['DruhSkoleni']);
                $recDokumentOsoby->addTimestampField('GSk_Datum', true, $rec['DatumVznikuPovinnosti']);

                $recDokumentOsoby->insertRecord();
            } catch (Exception $e) {
                MessageManager::addErrorMessage($e);
            }
        }
    }
}
